/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package jreqtools;


/**
* This is a file filter class to be used with the FileRequester.
* 
* @author	Markus Hillenbrand
*/

public abstract class FileFilter extends javax.swing.filechooser.FileFilter {
	
	/**
	* This is file filter which accepts all files by default.
	* 
	* @author	Markus Hillenbrand
	*/

	public final static class AllFilesFileFilter extends javax.swing.filechooser.FileFilter {
		
		public boolean accept(java.io.File arg0)  {
			return true;
		}

		public java.lang.String getDescription()  {
			return JReqTools.getResourceString("AllFiles");
		}

	}

	/**
	* This is file filter which accepts files by a given suffix.
	* 
	* @author	Markus Hillenbrand
	*/

	public final static class SuffixFileFilter extends javax.swing.filechooser.FileFilter {
		private String suffix, description;
		
		public SuffixFileFilter(String suffix, String description)  {
			this.description = description;
			this.suffix = suffix;
		}

		public boolean accept(java.io.File arg0)  {
			return arg0.toString().endsWith(suffix);
		}

		public java.lang.String getDescription()  {
			return description;
		}

	}

	public String toString()  {
		return getDescription();
	}

}
