/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package jreqtools;

import java.awt.event.*;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.GraphicsEnvironment;
import java.awt.Toolkit;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;
import jreqtools.gadgets.*;

/**
* This is a requester for fonts.
* 
* @author	Markus Hillenbrand
*/

public class FontRequester extends AbstractRequester {
	private Font 				font 			= null;
	private boolean				fixed			= false;
	private int 					answer			= CANCEL;
	private static final String []	fontList			= makeFontList();
	private static String []		fixedFontList	= null;
	
	private class Dialog extends JDialog {
		private	JList		names		= new JList();
		private	JList		size			= new JList();
		private	TextField	entersize	= new TextField("");
		private	FontShower	fontshower	= new FontShower();
		
		public Dialog(JFrame parent)  {
			super(parent, "JReqTools: FontRequester", true);
			
			// Gadgets einrichten
			size.setListData(new String [] { "6", "8", "10", "12", "14", "16", "18", "20", "24", "36", "48", "72" });
			size.setSelectedValue(""+FontRequester.this.font.getSize(), true);
			size.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
			entersize.setText(""+FontRequester.this.font.getSize());
			entersize.setColumns(3);
			names.setListData(fixed ? fixedFontList : fontList);
			names.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
			names.setSelectedValue(FontRequester.this.font.getName(), true);
			fontshower.setFont(FontRequester.this.font);
			
			size.addListSelectionListener(new ListSelectionListener() {
				public void valueChanged(ListSelectionEvent e) {
					if (e.getValueIsAdjusting()) return;
					entersize.setText((String)size.getSelectedValue());
					fontshower.setFont(createFont());
				}
			});
			names.addListSelectionListener(new ListSelectionListener() {
				public void valueChanged(ListSelectionEvent e) {
					if (e.getValueIsAdjusting()) return;
					fontshower.setFont(createFont());
				}
			});
			entersize.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					fontshower.setFont(createFont());
					size.setSelectedValue(entersize.getText(), true);
				}
			});
			
			// Buttons erzeugen
			OkCancelButtons buttons = new OkCancelButtons(FontRequester.this,
				new ActionListener() { public void actionPerformed(ActionEvent e) { ok(); } },
				new ActionListener() { public void actionPerformed(ActionEvent e) { cancel(); } },
				listener);
			
			// Listen erzeugen
			Box sizebox = Box.createVerticalBox();
			sizebox.add(new JScrollPane(size, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED));
			sizebox.add(entersize);
			Box lists = Box.createHorizontalBox();
			lists.add(new JScrollPane(names, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED));
			lists.add(new Strut());
			lists.add(sizebox);
			
			// Panel erzeugen
			JPanel p = new YFramePanel();
			p.add(lists);
			p.add(new Strut());
			p.add(fontshower);
			p.add(new Strut());
			p.add(buttons);
			
			// Alles hinzufgen
			setContentPane(p);
			getLayeredPane().add(new BackgroundImage(), new Integer(Integer.MIN_VALUE));
			pack();
		}

		private void cancel()  {
			answer = CANCEL;
			setVisible(false);
		}

		private void checkSize()  {
			String s = entersize.getText();
			
			StringChecker c = StringCheckers.getIntegerChecker();
			if (! c.accept(entersize.getText())) 
				{ 
				getToolkit().beep(); 
				entersize.setText("12"); 
				return; 
				}
			
			try
				{
				int size = Integer.parseInt(s);
				if (size < 6) { getToolkit().beep(); entersize.setText("6");  return; }
				if (size > 200) { getToolkit().beep(); entersize.setText("200");  return; }
				}
			catch (Exception x) { getToolkit().beep(); entersize.setText("12");  return; }
		}

		private Font createFont()  {
			checkSize();
			
			return new Font((String)names.getSelectedValue(), Font.PLAIN, Math.abs(Integer.parseInt(entersize.getText())));
		}

		private String [] getFixedFontList()  {
			/*String [] fonts = getToolkit().getFontList();
			
			Vector v = new Vector();
			for (int i=0; i<fonts.length; ++i)
				{
				FontMetrics fm = getToolkit().getFontMetrics(new Font(fonts[i], Font.PLAIN, 12));
				if (fm.charWidth('w') == fm.charWidth('i') && fm.charWidth('|') == fm.charWidth(' ')) v.addElement(fonts[i]);
				}
			
			int len = v.size();
			fonts = new String [len];
			for (int i=0; i<len; ++i) fonts[i] = (String) v.elementAt(i);
			
			return fonts;
			*/
			return null;
		}

		private void ok()  {
			FontRequester.this.answer = OK;
			FontRequester.this.font = createFont();
			setVisible(false);
		}

	}

	/**
	* Constructs a new StringRequester.
	*/

	public FontRequester()  {
		this("JReqTools: FontRequester", new Font("Monospaced", Font.PLAIN, 12));
	}

	/**
	* Constructs a new StringRequester.
	* 
	* @param	message - The message to be shown in the requester.
	* @param	defaultstring - The initial value of the text field.
	*/

	public FontRequester(String title)  {
		this(title, new Font("Monospaced", Font.PLAIN, 12));
	}

	/**
	* Constructs a new StringRequester.
	* 
	* @param	defaultstring - The initial value of the text field.
	*/

	public FontRequester(Font defaultfont)  {
		this("JReqTools: FontRequester",  defaultfont);
	}

	/**
	* Constructs a new StringRequester.
	* 
	* @param	title - Title of the requester.
	* @param	message - The message to be shown in the requester.
	* @param	defaultstring - The initial value of the text field.
	*/

	public FontRequester(String title, Font defaultfont)  {
		font = defaultfont;
	}

	protected javax.swing.JDialog createJDialog(JFrame parent)  {
		return new Dialog(parent);
	}

	public Font getFont()  {
		return font;
	}

	public String getFontAsString()  {
		String style = "";
		if (font.isBold() && font.isItalic())
			{
			style = "bi";
			}
		else if (font.isBold())
			{
			style = "b";
			}
		else if (font.isItalic())
			{
			style = "i";
			}
				
		return font.getName() + "/" + font.getSize() + style;
	}

	protected int getReturnValue()  {
		return answer;
	}

	protected static String [] makeFixedFontList()  {
		String [] result = GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames();
		
		JButton dummy = new JButton();
		Vector fixed = new Vector();
		
		for (int i=0; i<result.length; ++i)
			{
			Font font = new Font(result[i], Font.PLAIN, 12);
			FontMetrics fm = dummy.getFontMetrics(font);
			if (fm.charWidth('w') == fm.charWidth('i')) fixed.addElement(result[i]);
			}
		
		result = new String[fixed.size()];
		fixed.copyInto(result);
		
		return result;
	}

	protected static String [] makeFontList()  {
		return GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames();
	}

	public void setFixedWidthOnly(boolean bool)  {
		if (fixedFontList == null) fixedFontList = makeFixedFontList();
		fixed = bool;
	}

	public void setFont(Font newfont)  {
		font = newfont;
	}

}
