/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package jreqtools;

import java.awt.event.*;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import javax.swing.*;
import jreqtools.gadgets.*;

/**
* This is a requester for login purposes. A login name and a password is requested.
* 
* @author	Markus Hillenbrand
*/

public class LoginRequester extends AbstractRequester {
	private char [] 			password 	= null;
	private	String			login		= null;
	private String			message1	= null;
	private String			message2	= null;
	private String 			message	= null;
	private	int 				answer		= CANCEL;
	
	private class Dialog extends JDialog {
		private PasswordField 	passwordfield 	= new PasswordField("");
		private TextField		loginfield		= new TextField("");
		
		public Dialog(JFrame parent)  {
			super(parent, "JReqTools:LoginRequester", true);
			
			// Gadgets einrichten
			if (login != null) loginfield.setText(login);
			
			// Listener
			loginfield.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { passwordfield.requestFocus(); } });
			loginfield.addKeyListener(new KeyAdapter() { public void keyTyped(KeyEvent e) { if (e.getKeyChar() == KeyEvent.VK_ESCAPE) cancel(); } });
			passwordfield.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { ok(); } });
			passwordfield.addKeyListener(new KeyAdapter() { public void keyTyped(KeyEvent e) { if (e.getKeyChar() == KeyEvent.VK_ESCAPE) cancel();}});
			
			// Buttons erzeugen
			OkCancelButtons buttons = new OkCancelButtons(LoginRequester.this,
				new ActionListener() { public void actionPerformed(ActionEvent e) { ok(); } },
				new ActionListener() { public void actionPerformed(ActionEvent e) { cancel(); } },
				listener);
			
			Panel p1 = new Panel();
			p1.setLayout(new GridBagLayout());
			GridBagConstraints c = new GridBagConstraints();
			c.fill = GridBagConstraints.BOTH;
			c.weighty = 0;
			c.gridwidth = 1;
			c.gridheight = 1;
			
			c.gridx = 0; c.gridy = 0; c.weightx = 0; c.insets = JReqTools.getObjectInsets(0,0,-1,-1);
			p1.add(new JLabel(message1), c);
			c.gridx = 1; c.weightx = 1; c.insets = JReqTools.getObjectInsets(0,0,-1,0);
			p1.add(loginfield, c);
			
			c.gridx = 0; c.gridy = 1; c.weightx = 0; c.insets = JReqTools.getObjectInsets(0,0,0,-1);
			p1.add(new JLabel(message2), c);
			c.gridx = 1; c.weightx = 1; c.insets = JReqTools.getObjectInsets(0,0,0,0);
			p1.add(passwordfield, c);
			
			// Panel erzeugen
			JPanel p = new YFramePanel();
			p.add(Box.createVerticalGlue());
			p.add(new MessagePanel(message, p1));
			p.add(Box.createVerticalGlue());
			p.add(new Strut());
			p.add(buttons);
			
			// Alles hinzufgen
			setContentPane(p);
			getLayeredPane().add(new BackgroundImage(), new Integer(Integer.MIN_VALUE));
			pack();
		}

		private void cancel()  {
			answer = CANCEL;
			setVisible(false);
		}

		private void ok()  {
			answer = OK;
			login = loginfield.getText();
			password = passwordfield.getPassword();
			setVisible(false);
		}

		public void setVisible(boolean b)  {
			if (b) loginfield.requestFocus();
			super.setVisible(b);
		}

	}

	public LoginRequester()  {
		this("JReqTools: LoginRequester", null, JReqTools.getResourceString("Login"), JReqTools.getResourceString("Password"));
	}

	public LoginRequester(String msg, String loginMessage, String passwordMessage)  {
		this("JReqTools: LoginRequester", msg, loginMessage, passwordMessage);
	}

	public LoginRequester(String title, String msg, String loginMessage, String passwordMessage)  {
		setTitle(title);
		message	= msg;
		message1 	= loginMessage;
		message2 	= passwordMessage;
	}

	protected javax.swing.JDialog createJDialog(JFrame parent)  {
		return new Dialog(parent);
	}

	public String getLogin()  {
		return login;
	}

	public char [] getPassword()  {
		return password;
	}

	protected int getReturnValue()  {
		return answer;
	}

	public void setLogin(String text)  {
		login = text;
	}

	public void setMessage(String text)  {
		message = text;
	}

}
