/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package jreqtools;

import java.awt.event.*;
import javax.swing.*;
import jreqtools.gadgets.*;

/**
* This is a requester for passwords.
* 
* @author	Markus Hillenbrand
*/

public class PasswordRequester extends AbstractRequester {
	private char [] 			password 	= null;
	private String			message	= null;
	private	int 				answer		= CANCEL;
	
	private class Dialog extends JDialog {
		private PasswordField 	passwordfield 	= new PasswordField("");
		
		public Dialog(JFrame parent)  {
			super(parent, "JReqTools: PasswordRequester", true);
			
			// Listener
			passwordfield.addActionListener(new ActionListener() { public void actionPerformed(ActionEvent e) { ok(); } });
			passwordfield.addKeyListener(new KeyAdapter() { public void keyTyped(KeyEvent e) { if (e.getKeyChar() == KeyEvent.VK_ESCAPE) cancel(); } });
			
			// Buttons erzeugen
			OkCancelButtons buttons = new OkCancelButtons(PasswordRequester.this,
				new ActionListener() { public void actionPerformed(ActionEvent e) { ok(); } },
				new ActionListener() { public void actionPerformed(ActionEvent e) { cancel(); } },
				listener);
			
			// Panel erzeugen
			JPanel p = new YFramePanel();
			p.add(Box.createVerticalGlue());
			p.add(new MessagePanel(message, passwordfield));
			p.add(Box.createVerticalGlue());
			p.add(new Strut());
			p.add(buttons);
			
			// Alles hinzufgen
			setContentPane(p);
			getLayeredPane().add(new BackgroundImage(), new Integer(Integer.MIN_VALUE));
			pack();
		}

		private void cancel()  {
			answer = CANCEL;
			setVisible(false);
		}

		private void ok()  {
			answer = OK;
			password = passwordfield.getPassword();
			setVisible(false);
		}

		public void setVisible(boolean b)  {
			if (b) passwordfield.requestFocus();
			super.setVisible(b);
		}

	}

	public PasswordRequester()  {
		this("JReqTools: PasswordRequester", null);
	}

	public PasswordRequester(String message)  {
		this("JReqTools: PasswordRequester", message);
	}

	public PasswordRequester(String title, String message)  {
		setTitle(title);
		setMessage(message);
	}

	protected javax.swing.JDialog createJDialog(JFrame parent)  {
		return new Dialog(parent);
	}

	public char [] getPassword()  {
		return password;
	}

	protected int getReturnValue()  {
		return answer;
	}

	public void setMessage(String newmessage)  {
		message = newmessage;
	}

}
