/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package jreqtools;

import java.awt.event.*;
import javax.swing.*;
import jreqtools.gadgets.*;

/**
* This is a progress bar which pops up in an own dialog.
* 
* @author	Markus Hillenbrand
*/

public class ProgressTracker extends AbstractRequester {
	private	String			message		= null;
	private	ProgressTask	task			= null;
	private	boolean			done			= false;
	private boolean			cancelButton	= false;
	
	private class Dialog extends JDialog {
		private JProgressBar	progressbar = new JProgressBar(JProgressBar.HORIZONTAL);
		private	TextField		text			= new TextField("-");
		private	Timer			timer		= null;
		
		public Dialog(JFrame parent)  {
			super(parent, "JReqTools: ProgressTracker", true);
			
			// Gadgets initialisieren
			progressbar.setPreferredSize(new java.awt.Dimension(400,75));
			progressbar.setMaximumSize(new java.awt.Dimension(Short.MAX_VALUE, Short.MAX_VALUE));
			text.setBorder(BorderFactory.createEmptyBorder());
			text.setEditable(false);
			text.setOpaque(false);
			
			// Panel 2 erzeugen
			Panel p2 = new Panel();
			p2.setLayout(new BoxLayout(p2, BoxLayout.X_AXIS));
			p2.add(text);
			if (cancelButton)
				{
				final JButton button = new JButton(JReqTools.getResourceString("Cancel"), UIManager.getIcon("jreqtools.cancelIcon"));
				button.addActionListener(new ActionListener() {
					public void actionPerformed(ActionEvent e) {
						button.setEnabled(false);
						task.cancel();
					}
				});
				p2.add(new Strut());
				p2.add(button);
				}
			
			// Panel 1 erzeugen
			Panel p1 = new Panel();
			p1.setLayout(new BoxLayout(p1, BoxLayout.Y_AXIS));
			p1.add(progressbar);
			p1.add(new Strut());
			p1.add(p2);
			
			// Hintergrundfarbe
			text.setBackground(p1.getBackground());
			
			// Panel erzeugen
			JPanel p = new YFramePanel();
			p.add(new MessagePanel(message, p1));
			
			// Alles hinzufgen
			setContentPane(p);
			getLayeredPane().add(new BackgroundImage(), new Integer(Integer.MIN_VALUE));
			pack();
		}

		public void setVisible(boolean b)  {
			if (! b)
				{
				super.setVisible(false);
				return;
				}
			
			progressbar.setMinimum(task.getMinimum());
			progressbar.setMaximum(task.getMaximum());
			progressbar.setValue(task.getCurrent());
			
			ActionListener l = new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					if (done) 
						{
						timer.stop();
						timer = null;
						setVisible(false);
						}
					text.setText(task.getCurrentText());
					progressbar.setMinimum(task.getMinimum());
					progressbar.setMaximum(task.getMaximum());
					progressbar.setValue(task.getCurrent());
					}
				};
			
			timer = new Timer(1000, l);
			timer.start();
			
			super.setVisible(true);
		}

	}

	private class UserThread extends Thread {
		
		public UserThread()  {
			super("JReqTools.ProgressTracker.UserThread");
			
			setPriority(MIN_PRIORITY);
		}

		public void run()  {
			try { sleep(100); } catch (InterruptedException x) {}
			
			done = false;
			
			try
				{
				task.run();
				}
			catch (Exception x) { JReqTools.showException(x); }
			
			done = true;
		}

	}

	public ProgressTracker(ProgressTask task)  {
		this("JReqTools: ProgressTracker", null, task);
	}

	public ProgressTracker(String message, ProgressTask task)  {
		this("JReqTools: ProgressTracker", message, task);
	}

	public ProgressTracker(String title, String message, ProgressTask task)  {
		setTitle(title);
		setMessage(message);
		this.task = task;
	}

	public void addCancelButton(boolean bool)  {
		cancelButton = bool;
	}

	protected javax.swing.JDialog createJDialog(JFrame parent)  {
		return new Dialog(parent);
	}

	protected int getReturnValue()  {
		return OK;
	}

	public void setMessage(String newmessage)  {
		message = newmessage;
	}

	public void start()  {
		start(null);
	}

	public void start(JFrame parent)  {
		Thread t = new UserThread();
		t.start();
		
		request(parent);
	}

}
