/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package jreqtools;

import java.awt.event.*;
import javax.swing.*;
import jreqtools.gadgets.*;

/**
* This is a requester for complete texts.
* 
* @author	Markus Hillenbrand
*/

public class TextRequester extends AbstractRequester {
	private String 			string 		= "";
	private String			message	= null;
	private	int 				answer		= CANCEL;
	
	private class Dialog extends JDialog {
		private	JTextArea 	textfield 	= new JTextArea(TextRequester.this.getText());
		private	JScrollPane	scrollpane	= new JScrollPane(textfield);
		
		public Dialog(JFrame parent)  {
			super(parent, "JReqTools: TextRequester", true);
			
			// Listener
			textfield.addKeyListener(new KeyAdapter() { public void keyTyped(KeyEvent e) { if (e.getKeyChar() == KeyEvent.VK_ESCAPE) cancel(); } });
			
			// Gadgets einrichten
			scrollpane.setPreferredSize(new java.awt.Dimension(200,200));
			
			// Buttons erzeugen
			OkCancelButtons buttons = new OkCancelButtons(TextRequester.this,
				new ActionListener() { public void actionPerformed(ActionEvent e) { ok(); } },
				new ActionListener() { public void actionPerformed(ActionEvent e) { cancel(); } },
				listener);
			
			// Panel erzeugen
			JPanel p = new YFramePanel();
			p.add(new MessagePanel(message, scrollpane));
			p.add(new Strut());
			p.add(buttons);
			
			// Alles hinzufgen
			setContentPane(p);
			getLayeredPane().add(new BackgroundImage(), new Integer(Integer.MIN_VALUE));
			pack();
		}

		private void cancel()  {
			answer = CANCEL;
			setVisible(false);
		}

		private void ok()  {
			answer = OK;
			setString(textfield.getText());
			setVisible(false);
		}

		public void setVisible(boolean b)  {
			if (b) textfield.requestFocus();
			super.setVisible(b);
		}

	}

	/**
	* Constructs a new StringRequester.
	*/

	public TextRequester()  {
		this("JReqTools: TextRequester", null, "");
	}

	/**
	* Constructs a new StringRequester.
	* 
	* @param	defaultstring - The initial value of the text field.
	*/

	public TextRequester(String defaultstring)  {
		this("JReqTools: TextRequester", null, defaultstring);
	}

	/**
	* Constructs a new StringRequester.
	* 
	* @param	message - The message to be shown in the requester.
	* @param	defaultstring - The initial value of the text field.
	*/

	public TextRequester(String message, String defaultstring)  {
		this("JReqTools: TextRequester", message, defaultstring);
	}

	/**
	* Constructs a new StringRequester.
	* 
	* @param	title - Title of the requester.
	* @param	message - The message to be shown in the requester.
	* @param	defaultstring - The initial value of the text field.
	*/

	public TextRequester(String title, String message, String defaultstring)  {
		setTitle(title);
		setMessage(message);
		setText(defaultstring);
	}

	protected javax.swing.JDialog createJDialog(JFrame parent)  {
		return new Dialog(parent);
	}

	protected int getReturnValue()  {
		return answer;
	}

	/**
	* Gets the string which has been entered by the user.
	*/

	public String getText()  {
		return string;
	}

	/**
	* Sets the message to be shown in the requester.
	*/

	public void setMessage(String newmessage)  {
		message = newmessage;
	}

	/**
	* Sets the string in the requester.
	*/

	public void setString(String newstring)  {
		string = newstring;
	}

	/**
	* Sets the string in the requester.
	*/

	public void setText(String newstring)  {
		string = newstring;
	}

}
